==> whmcs-9.0.0-release.1.zip: resources/views/admin/billing/invoice/index.php <==
<?php //ICB0 82:0 83:104f                                                     ?><?php //00cba
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version: 9.0.0 (9.0.0-release.1)                                      *
// * BuildId: db1c908403.748                                               *
// * Build Date: 20 Jan 2026                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPtBStsE08YHKBMzAGF0lri9Lh0ifzMh10j8ZErjwx7KNSmUppVl947MTGBk1otv/QndhhE8B
2PR+4R2kSW2vfFInr2/yeTMrdGeiHztK0CIU9CkO23/BTIiChjsyAKPyvYztRjveJeEcYEgfxovs
KOg583LNYQASx5yeuCEAcXyTo9pXlLE2je29CJMDCEbEvJFk9RvglPkuBrzecv3JpM1E2WFk6pST
5JQurNpFvCFnaRyD9g/eWvGb61lvMVk8NxUhkaqCUxf1dv39o5R+DOEpma5Wtx1W6WL9UvGGdEbg
IbD7Jd4CSWCgS4mbZk2MYi3rOLxe+vWByDBY14RTbN8tqSmm0DlqYD0uJ+OB32nyvIIeZkSq2Dqz
byGhB4+sBfN6cF0ZGPQ+GIbGsHGXUwbLlExXTSIHp7rQrPskR1/bJQfADXw8810TlcjiNvADLdQq
GG1wAqHnd7MGzaLj1ptBjH2f3lYyfEw3fiu1M5cKn48BgYQ2S9tMci2yYKsUXSGZcK4fuPYpgkcU
MKZXd6Lrh+6UXngvgEdnYfJ85Lz3nM6E2TwOPKSik4D0I4zgAMhBZfpiSzQ6Rw1hqfLBUUH/U5OF
7Ypo5xrDpVp8OHvgDyfKny35nmdKjta0DfwOLXRxFJ22ThXuF//UVhfxD26cAqhBf8uw3Q0NeK9l
SYp3J3VIyxS7om92G6dPHFjJV94zPjZEbZ7SVn/VhTIUYucJY6Ci4HVKXeO2rhlCRwhrCAr1HGa3
4K7Y+ew0OdN86Csnqr70Mg58p2jC4vpJOKf9sMNqM/OOIj43uQ18XDqpFr8KgA8HFMuUYPG8Cmkj
TpkAf+UX//xEgGzAdKquC5JSu8757+6BLVq/K60wtJlMwElTl7PuQAx9lRdHKDW==
HR+cPwguAfmvcA/Jj0Q/lrvFaNbBCwhu88Lwa9h8PMsCuMuDaJfX3FyRnILrbYCb2yBPTJQNsQxy
udRLHVDweu9/Fz9jgjZsncD4yofcNK6W9jSqiT7gYiXnmh7uGiOIiHkN6qYBFRvivHgTW/qsXWYp
0452GdxcPKvavjsiboZe8aC5SNxeK7arllggDOVQmvnRqVpboug+W3glf1qs4KB5ivICCp1LLbBf
HuT5QX0Dr8WDUPN6oCm5OJZvECE6pVT0dlJNJ574f3WHE9pGE4DBiGyao+H1bQIfaguz2yDiSNV5
qweMS+rVzZQYyy7O5ooVJHGs5VyTYmdAAAUSmEXGvCt0+m5aL6g8WBKcnIYcRjU3RiVyzE1bB5Ac
rGc2zuq4z+7yv3x50DIxS1utvDx/pkoo/jrDMeyCvmGlEHpBPX80D3lQxiKUqXn7U2pBK0vuj3a8
3u48jbO3ZUneu1OgcgL8ATvciYnBaBYhOIoN2ZhO84g411NIUV0KLaOA0YZo5o5XOG1VkcRkZw/6
+Xq4Esw8jh8F5wL1G3+9PD96735lD/6JpJyTZzF10BiwpqoGdpvNXernnyTk4/4zOd87QbIxqaCK
qbsKnODmRDzbpfpMDsaPDWSo693b2dcELfZK3wrdqfoR9LwLghIwwFMKmxHhRBDPeQ9qASYTokje
EoCTp/8QxJk+mtKbShuDXYAbYDhumJvzhEBF5BxzBMazswCN7zCz2c6QgE6CTVuDsAJ6QOT8Wlva
bXoDNhvSKFaoV2JNbpRCm2a7Zsow1xthhT9//rD1zHp8s4Ks0ukHTNP1Q/oY4PbfzM5CssL2gPd6
4SQY2n/hr16d73vBS9s16NYW/dVDI+MAnixvAvb+5i768/O1tlmYf6/FitC=

==> whmcs-9.0.1-release.1.zip: resources/views/admin/billing/invoice/index.php <==
<?php //ICB0 82:0 83:104f                                                     ?><?php //00cba
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version: 9.0.1 (9.0.1-release.1)                                      *
// * BuildId: 81d80f82cb.790                                               *
// * Build Date: 05 Feb 2026                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPvILvJ2YUDu7ooPm4zVfYcuJ9Nv45VQGnFkysknJ4TLv0rdN4ykL9xW0BWjv8csVLVXUbYzK
bJRekVTwSYuHlCfSRV5mi8ZOuaAhkmQTR5c8Zo3vNOuDmzp1YnP9M4j9+zLfADk0GSlE917b/l0v
kIqW2PikfIbWD3XHrOKaAH7A0siMb291PvY7/0E4/iupkw/b06+DvBiNSy3/mcPPiGGmaraCVMot
nQRSS9OTCR6qwg23B/2A5ZGBfw4NFHF3/HpEVk24ZeQS79htcamfsbXsAdrEY92o2vVJQbsUbtVn
uXy1ZMwgQBk7Nt39zcGxI4X1gaRL2RKNEc+ukkguFJv2pELoSi3Q+F7AQG1Zf2Suo2WsJUB97cXf
N2FCeWVCgx4A7HMhOVqMQddBz19Sp9pFLC03jmS5BCE4nrzRgRzskh4DYHWWu2YCiaEWmr/j5Wwd
DPYMa8OHwR+2HOWdOB0g/GTTywc8YNN5XcNNncheRdNWXu0mNBAXz72b65dI71ySVXFRq+D3a6ps
EO4elRZRq3f/DLu3JK5X7ZMdwAZWYM9kp22ifn8BOZvUP4ofHS9ftejRO06RiMfdghQKVkdg1mok
e6aef/nSXfuWALRTbqvdJNodEF0lu00ENf1qVn7GHh/QgQTidQB8YThW4e80XpBN6gsI6A3UgPsG
9oea2YGtDbcZcSZn1gPWv7hWvwCt3W9Ds0cFg1ZddXpQ7+gQxObtGWtKubLmvIMGY71OvkahMpfJ
94fPihoeMF6MZeaXY8XVFzy4WP6oT0nsbl4o00Ay6rYcLfN+1Y7K9SQ9P1rcU9wuruEEdlqZ2538
tGunFT1nNn4wddYs68QvMBX0MBzYhNVxuKZ8Pdj7En2LAablRSn228D5hFB9ZaK==
HR+cPs7aUgHpD5+CUbhlXsv2b5p180iopErW9gJ8mFkiLh8FBSdvs17pKw9S0dkn+mc4EByEz7Ar
iL7HRZ8gRc30B0oWGx72H1dT8JP9Jwc83M5ObPIaTVzQ+QnV52/KwiLB6Ie+QZQz5qsJGsa1mwld
o0gNUm48foZtojEDvOVjIEZT8AuBDa8fkZR/csBh240jQGIoLKlmwxtrppwgpxgrvQlqHWqsizH8
tRIeUy28wcZYsaFtuBLs61BFsk48Q8D2xfTLCSHw7XLyG6ErvKekUcTdEnnby5SgAYU7OIt6ptUw
Pu4TSFsALs0hXCsn5A5DK31DSoYjCId/61vcV90iwMZr4G4tQWQRhVZcCUBjoUuolIMWFP5hOF30
Zs/gayrcrc874DkMYklez8TMAtMQVDJ0XgqdC8uQMOgc1Q1upTbheR84TxEHXH/b0AkNJ+y+b2Ay
7bfJ9pXtwjYaxqfROn/4UuX+Iyh+FoeLrPQe/yv2BUQP9uHp7vkW6+GJYE8hoqrkzRrMfiEIToAr
w4Xi2V48HrUS0TNe7l8BBVUDMw6EzMhjlr3G1fm3X8lxp7Nx2sb1qrjO6AaXxXbqOrqefQTcZY/h
zNVbQfXm7ZtS3zxEEZJmaYcIhCqS4tEdrNoQVl91YoWYWHCPHaFGAatQ5vdgHxwblTD4J/IVag6U
4NsVgoDfAjvAYMUMkq+N/PWEvX61NERBvzxaLToym75xvL4/QiqusR7n0e30Jk7fx03yB2W7H0p8
oQFpffnDAVJpZPZieL2ADjY45GXGSg5/LOFivBvHrkfZzLglCDZR+vBpcvogyWM3x+weHuqwNcqn
g/r930BoylBnaYUq2bNT3gX1ssdPqJrYHyD/zcKcmV/4OnzgnS6D8fhqcBcvJDuUIW==
